@@ -6,7 +6,14 @@ MIT license
 
 from synthtiger import components, layers, templates, utils
 from synthtiger._version import __version__
-from synthtiger.gen import generator, read_config, read_template
+from synthtiger.gen import (
+    generator,
+    get_global_random_states,
+    read_config,
+    read_template,
+    set_global_random_seed,
+    set_global_random_states,
+)
 
 __all__ = [
     "components",
@@ -14,6 +21,9 @@ __all__ = [
     "templates",
     "utils",
     "generator",
+    "get_global_random_states",
     "read_config",
     "read_template",
+    "set_global_random_seed",
+    "set_global_random_states",
 ]
